@@ -115,7 +115,7 @@ FT12wrap::setup()
   if (cfg->value("device","").length() > 0)
     {
       if (cfg->value("ip-address","").length() > 0 ||
-          cfg->value("port",-1) != -1)
+          cfg->value("dest-port",-1) != -1)
         {
           ERRORPRINTF (t, E_ERROR | 5, "Don't specify both device and IP options!");
           return false;
@@ -377,10 +377,9 @@ FT12wrap::process_read(bool is_timeout)
           else if (akt[4] == (recvflag ? 0xD3 : 0xF3))
             {
               recvflag = !recvflag;
-              CArray *c = new CArray;
-              c->setpart (akt.data() + 5, 0, len - 7);
-              last = *c;
-              LowLevelFilter::recv_Data (*c);
+              CArray c(akt.data() + 5, 0, len - 7);
+              last = c;
+              LowLevelFilter::recv_Data (c);
             }
           akt.deletepart (0, len);
         }
