@@ -31,6 +31,9 @@
 #include "log.h"
 #include "cm_tp1.h"
 
+/* add formatter for fmt >= 10.0.0 */
+int format_as(LPDU_Type t) { return t; }
+
 class TPUARTserial : public LLserial
 {
 public:
@@ -128,7 +131,7 @@ TPUARTwrap::setup()
   if (cfg->value("device","").length() > 0)
     {
       if (cfg->value("ip-address","").length() > 0 ||
-          cfg->value("port",-1) != -1)
+          cfg->value("dest-port",-1) != -1)
         {
           ERRORPRINTF (t, E_ERROR | 25, "Don't specify both device and IP options!");
           return false;
@@ -346,7 +349,7 @@ TPUARTwrap::timer_cb(ev::timer &, int)
       setstate(T_wait);
       break;
     case T_wait_keepalive:
-      if (retry < 3)
+      if (retry > 2)
         {
           setstate(T_in_reset);
           return;
@@ -364,6 +367,12 @@ TPUARTwrap::enableInputParityCheck()
 {
   struct termios t1;
 
+  if (fd_driver == nullptr)
+  {
+    // Not possible and not necessary to enable on TCP connections, so just continue.
+    return 0;
+  }
+
   TRACEPRINTF (t, 8, "Enabling input parity check on fd %d\n", fd_driver->get_fd());
 
   if (tcgetattr (fd_driver->get_fd(), &t1))
@@ -642,8 +651,13 @@ TPUARTwrap::setstate(enum TSTATE new_state)
 
     case T_wait_keepalive:
     {
+      if (state == T_wait_keepalive)
+        retry++;
+      else
+        retry = 1;
+
       uint8_t c = 0x02;
-      TRACEPRINTF (t, 0, "Send GetState %02X", c);
+      TRACEPRINTF (t, 0, "Send keepalive GetState %02X", c);
       LowLevelIface::send_Data(c);
       timer.start(0.5,0);
       break;
